<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\OrderAdditionalData\Setup;

use Magento\Framework\DB\Ddl\Table;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\UpgradeSchemaInterface;
use Magento\Sales\Model\Order\StatusFactory;

/**
 * Class UpgradeSchema
 * @package FiloBlu\OrderAdditionalData\Setup
 */
class UpgradeSchema implements UpgradeSchemaInterface
{
    /**
     * @var StatusFactory
     */
    protected $statusFactory;

    /**
     * UpgradeSchema constructor.
     * @param StatusFactory $statusFactory
     */
    public function __construct(StatusFactory $statusFactory)
    {
        $this->statusFactory = $statusFactory;
    }

    /**
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;
        $installer->startSetup();

        if (version_compare($context->getVersion(), '1.0.5') < 0) {

            // Get module table
            $connection = $installer->getConnection();

            $orderTable = $installer->getTable('sales_order');

            if ($setup->getConnection()->isTableExists($orderTable) == true) {
                // Declare data
                $connection->addColumn(
                    $orderTable,
                    'fbnetsuite_base_theoric_shipping_amount',
                    [
                        'type'     => Table::TYPE_DECIMAL,
                        'length'   => '12,4',
                        'default'  => 0,
                        'nullable' => false,
                        'comment'  => 'Base Theoric Shipping Amount (Free Shipping)',
                    ]
                );

                $connection->addColumn(
                    $orderTable,
                    'fbnetsuite_theoric_shipping_amount',
                    [
                        'type'     => Table::TYPE_DECIMAL,
                        'length'   => '12,4',
                        'default'  => 0,
                        'nullable' => false,
                        'comment'  => 'Theoric Shipping Amount (Free Shipping)'
                    ]
                );
            }

            $itemTable = $installer->getTable('sales_order_item');

            if ($setup->getConnection()->isTableExists($itemTable) == true) {
                // Declare data
                $connection->addColumn(
                    $itemTable,
                    'kpi_full_price',
                    [
                        'type'     => Table::TYPE_DECIMAL,
                        'length'   => '12,4',
                        'default'  => 0,
                        'nullable' => false,
                        'comment'  => 'Product Full Price',
                    ]
                );
            }
        }

        if (version_compare($context->getVersion(), '1.1.5') < 0) {
            $shipmentTable = $installer->getTable('sales_shipment');
            // Get module table
            $connection = $installer->getConnection();
            if ($setup->getConnection()->isTableExists($shipmentTable) == true) {
                // Declare data
                $connection->addColumn(
                    $shipmentTable,
                    'order_increment_id',
                    [
                        'type'     => Table::TYPE_TEXT,
                        'length'   => '50',
                        'default'  => null,
                        'nullable' => true,
                        'comment'  => 'Order Increment ID',
                    ]
                );
            }
        }

        if(version_compare($context->getVersion(), '1.1.7') < 0)
        {
            $connection = $installer->getConnection();

            $connection->addColumn(
                $setup->getTable('sales_order_grid'),
                'ext_order_id',
                [
                    'type' => Table::TYPE_BOOLEAN,
                    'default' => 0,
                    'comment' => 'External Order Id'
                ]
            );
            $connection->addColumn(
                $setup->getTable('sales_order_grid'),
                'ext_customer_id',
                [
                    'type' => Table::TYPE_BOOLEAN,
                    'default' => 0,
                    'comment' => 'External Customer Id'
                ]
            );
        }

        $installer->endSetup();
    }
}
